@@ -3,7 +3,7 @@ import contextlib
 import functools
 import uuid
 from datetime import timedelta
-from typing import Any, Optional, override
+from typing import Any, Optional, override, Protocol, TYPE_CHECKING
 
 from nonebot import on_fullmatch, on_message
 from nonebot.log import logger
@@ -15,6 +15,10 @@ from ..help_doc import descript, message_alia
 from ..utils import Result, debug_log, export
 from .send_ark import SendArk
 
+if TYPE_CHECKING:
+    class _ApiCall(Protocol):
+        async def __call__(self, **kwargs: Any) -> Any: ...
+
 with contextlib.suppress(ImportError):
     from nonebot.adapters.onebot.v11 import (
         ActionFailed,
@@ -140,7 +144,7 @@ with contextlib.suppress(ImportError):
                 raise RuntimeError(raise_text) from result.error
             return result
 
-        def __getattr__(self, name: str):
+        def __getattr__(self, name: str) -> "_ApiCall":
             if name.startswith("__") and name.endswith("__"):
                 raise AttributeError(
                     f"'{self.__class__.__name__}' object has no attribute '{name}'"
@@ -200,7 +204,7 @@ with contextlib.suppress(ImportError):
         @debug_log
         async def img_summary(self, summary: str, url: Optional[str] = None) -> None:
             if url is None:
-                from ...code_context import Context
+                from ...context import Context
 
                 url = Context.get_context(self.session).ctx.get("gurl")
 
