@@ -3,6 +3,7 @@ import functools
 import inspect
 from typing import (
     Any,
+    Awaitable,
     Callable,
     ClassVar,
     Coroutine,
@@ -50,6 +51,16 @@ def export[**P, R](call: Callable[P, R]) -> Callable[P, R]:
 type Coro[T] = Coroutine[None, None, T]
 
 
+def is_coroutine_callable(call: Callable[..., Any]) -> TypeIs[Callable[..., Coro[Any]]]:
+    """检查 call 是否是一个 callable 协程函数"""
+    if inspect.isroutine(call):
+        return inspect.iscoroutinefunction(call)
+    if inspect.isclass(call):
+        return False
+    func = getattr(call, "__call__", None)
+    return inspect.iscoroutinefunction(func)
+
+
 @overload
 def debug_log[**P, R](call: Callable[P, Coro[R]]) -> Callable[P, Coro[R]]: ...
 
@@ -59,20 +70,17 @@ def debug_log[**P, R](call: Callable[P, R]) -> Callable[P, R]: ...
 
 
 def debug_log[**P, R](call: Callable[P, Coro[R] | R]) -> Callable[P, Coro[R] | R]:
-    def log(*args: P.args, **kwargs: P.kwargs):
-        logger.debug(f"{call.__name__}: args={args}, kwargs={kwargs}")
-
-    if inspect.iscoroutinefunction(call):
+    if is_coroutine_callable(call):
         # 本来应该用 # pyright: ignore[reportRedeclaration]
         # 但是格式化后有点难绷，所以直接用了 # type: ignore
         async def wrapper(*args: P.args, **kwargs: P.kwargs) -> R:  # type: ignore
-            log(*args, **kwargs)
+            logger.debug(f"{call.__name__}: args={args}, kwargs={kwargs}")
             return await cast(Callable[P, Coro[R]], call)(*args, **kwargs)
 
     else:
 
         def wrapper(*args: P.args, **kwargs: P.kwargs) -> R:
-            log(*args, **kwargs)
+            logger.debug(f"{call.__name__}: args={args}, kwargs={kwargs}")
             return cast(Callable[P, R], call)(*args, **kwargs)
 
     return functools.update_wrapper(wrapper, call, assigned=WRAPPER_ASSIGNMENTS)
@@ -161,13 +169,12 @@ def _send_message(limit: int):
         if key in call_cnt:
             del call_cnt[key]
 
-    async def send_message(
-        bot: Bot,
+    def send_message(
         session: Session,
         target: Optional[Target],
         message: T_Message,
-    ) -> Receipt:
-        key = hash(f"{id(bot)}${id(session)}")
+    ) -> Awaitable[Receipt]:
+        key = id(session)
         if key not in call_cnt:
             call_cnt[key] = 1
             asyncio.get_event_loop().call_later(60, clean_cnt, key)
@@ -177,8 +184,11 @@ def _send_message(limit: int):
         else:
             call_cnt[key] += 1
 
-        message = await as_unimsg(message)
-        return await message.send(target, bot)
+        async def send_message_inner():
+            msg = await as_unimsg(message)
+            return await msg.send(target)
+
+        return asyncio.create_task(send_message_inner())
 
     return send_message
 
@@ -186,26 +196,27 @@ def _send_message(limit: int):
 send_message = _send_message(limit=6)
 
 
-async def send_forward_message(
-    bot: Bot,
+def send_forward_message(
     session: Session,
     target: Optional[Target],
     msgs: Iterable[T_Message],
-) -> Receipt:
+) -> Awaitable[Receipt]:
     async def create_node(msg: T_Message) -> CustomNode:
         return CustomNode(
-            uid=bot.self_id,
+            uid="0",
             name="forward",
             content=await as_unimsg(msg),
         )
 
-    nodes = await asyncio.gather(*[create_node(msg) for msg in msgs])
-    return await send_message(
-        bot=bot,
-        session=session,
-        target=target,
-        message=Reference(nodes=nodes),
-    )
+    async def send_forward_inner():
+        nodes = await asyncio.gather(*[create_node(msg) for msg in msgs])
+        return await send_message(
+            session=session,
+            target=target,
+            message=Reference(nodes=nodes),
+        )
+
+    return asyncio.create_task(send_forward_inner())
 
 
 def _export_manager():
@@ -223,7 +234,7 @@ def _export_manager():
         return f(config.group, str(x))
 
     def export_manager(ctx: T_Context) -> None:
-        from ..code_context import Context
+        from ..context import Context
 
         ctx["get_ctx"] = Context.get_context
         ctx["set_usr"] = set_usr
